localizer package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   localizer.supported_file_types

Submodules
----------

localizer.FileHandler module
----------------------------

.. automodule:: localizer.FileHandler
   :members:
   :undoc-members:
   :show-inheritance:

localizer.examples module
-------------------------

.. automodule:: localizer.examples
   :members:
   :undoc-members:
   :show-inheritance:

localizer.language\_pack module
-------------------------------

.. automodule:: localizer.language_pack
   :members:
   :undoc-members:
   :show-inheritance:

localizer.print\_replace module
-------------------------------

.. automodule:: localizer.print_replace
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: localizer
   :members:
   :undoc-members:
   :show-inheritance:
